About Sigma Quantiphi
============

`Sigma Quantiphi <https://www.sigmaquantiphi.com/>`_ is a quantitative-engineering firm that builds end-to-end algorithmic-trading systems for the cryptocurrency markets.
We create open-source, Python-first tools—like crypto-pandas—and deliver turnkey execution, data, and research pipelines that emphasize simplicity, transparency, and rapid deployment.

If you want to know more or work with us, contact us at contact@sqphi.com.